CarouselNavigationButtons class

Inheritance

Constructors

CarouselNavigationButtons({Key? key, required int slidesCount, required bool repeat, required Duration transitionDuration, required Curve transitionCurve, VoidCallback? onSkip, VoidCallback? onDone, bool showNextButton = false, Widget? skipLabel, Widget? nextLabel, Widget? doneLabel, ButtonStyle? buttonStyle, NavigationButtonBuilder? skipButtonBuilder, NavigationButtonBuilder? nextButtonBuilder, NavigationButtonBuilder? doneButtonBuilder, AlignmentGeometry skipAlignment = Alignment.topRight, AlignmentGeometry nextAlignment = Alignment.bottomRight, EdgeInsetsGeometry padding = const EdgeInsets.all(16)})
const

Properties

buttonStyle ButtonStyle?
final
doneButtonBuilder NavigationButtonBuilder?
final
doneLabel Widget?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
nextAlignment AlignmentGeometry
final
nextButtonBuilder NavigationButtonBuilder?
final
nextLabel Widget?
final
onDone VoidCallback?
final
onSkip VoidCallback?
final
padding EdgeInsetsGeometry
final
repeat bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showNextButton bool
final
skipAlignment AlignmentGeometry
final
skipButtonBuilder NavigationButtonBuilder?
final
skipLabel Widget?
final
slidesCount int
final
transitionCurve Curve
final
transitionDuration Duration
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited